searchData={"content_type":"text/markdown","items":[{"doc":"ExConstructor is an Elixir library that makes it easy to instantiate\nstructs from external data, such as that emitted by a JSON parser.\n\nAdd `use ExConstructor` after a `defstruct` statement to inject\na constructor function into the module.\n\nThe generated constructor, called `new` by default,\nhandles map-vs-keyword-list, string-vs-atom-keys, and\ncamelCase-vs-under_score input data issues automatically,\nDRYing up your code and letting you move on to the interesting\nparts of your program.","ref":"ExConstructor.html","title":"ExConstructor","type":"module"},{"doc":"1. Add ExConstructor to your list of dependencies in `mix.exs`:\n\n        def deps do\n          [{:exconstructor, \"~> 1.2.9\"}]\n        end","ref":"ExConstructor.html#module-installation","title":"Installation - ExConstructor","type":"module"},{"doc":"Example:\n\n    defmodule TestStruct do\n      defstruct field_one: 1,\n                field_two: 2,\n                field_three: 3,\n                field_four: 4,\n      use ExConstructor\n    end\n\n    TestStruct.new(%{\"field_one\" => \"a\", \"fieldTwo\" => \"b\", :field_three => \"c\", :FieldFour => \"d\"})\n    # => %TestStruct{field_one: \"a\", field_two: \"b\", field_three: \"c\", field_four: \"d\"}\n\nFor advanced usage, see `__using__/1` and `populate_struct/3`.","ref":"ExConstructor.html#module-usage","title":"Usage - ExConstructor","type":"module"},{"doc":"ExConstructor is copyright 2016-2021 Appcues, Inc.\n\nExConstructor is released under the\n[MIT License](https://github.com/appcues/exconstructor/blob/master/LICENSE.txt).","ref":"ExConstructor.html#module-authorship-and-license","title":"Authorship and License - ExConstructor","type":"module"},{"doc":"`use ExConstructor` defines a constructor for the current module's\nstruct.\n\nIf `name_or_opts` is an atom, it will be used as the constructor name.\nIf `name_or_opts` is a keyword list, `name_or_opts[:name]` will be\nused as the constructor name.\nBy default, `:new` is used.\n\nAdditional options in `name_or_opts` are stored in the\n`@exconstructor_default_options` module attribute.\n\nThe constructor is implemented in terms of `populate_struct/3`.\nIt accepts a map or keyword list of keys and values `map_or_kwlist`,\nand an optional `opts` keyword list.\n\nKeys of `map_or_kwlist` may be strings or atoms, in camelCase or\nunder_score format.\n\n`opts` may contain keys `strings`, `atoms`, `camelcase` and `underscore`.\nSet these keys false to prevent testing of that key format in\n`map_or_kwlist`.  All default to `true`.\n\nFor the default name `:new`, the constructor's definition looks like:\n\n    @spec new(ExConstructor.map_or_kwlist, Keyword.t) :: %__MODULE__{}\n    def new(map_or_kwlist, opts \\\\ []) do\n      ExConstructor.populate_struct(%__MODULE__{}, map_or_kwlist, Keyword.merge(@exconstructor_default_options, opts))\n    end\n    defoverridable [new: 1, new: 2]\n\nOverriding `new/2` is allowed; the generated function can be called by\n`super`.  Example uses include implementing your own `opts` handling.","ref":"ExConstructor.html#__using__/1","title":"ExConstructor.__using__/1","type":"macro"},{"doc":"Alias for `__using__`, for those who prefer an explicit invocation.","ref":"ExConstructor.html#define_constructor/1","title":"ExConstructor.define_constructor/1","type":"macro"},{"doc":"Returns a copy of `struct` into which the values in `map_or_kwlist`\nhave been applied.\n\nKeys of `map_or_kwlist` may be strings or atoms, in camelCase or\nunder_score format.","ref":"ExConstructor.html#populate_struct/2","title":"ExConstructor.populate_struct/2","type":"function"},{"doc":"Returns a copy of `struct` into which the values in `map_or_kwlist`\nhave been applied.\n\nKeys of `map_or_kwlist` may be strings or atoms, in camelCase,\nUpperCamelCase, or under_score format.\n\n`opts` may contain keys `strings`, `atoms`, `camelcase`, `uppercamelcase`,\nand `underscore`.\nSet these keys false to prevent testing of that key format in\n`map_or_kwlist`.  All default to `true`.","ref":"ExConstructor.html#populate_struct/3","title":"ExConstructor.populate_struct/3","type":"function"},{"doc":"","ref":"ExConstructor.html#t:map_or_kwlist/0","title":"ExConstructor.map_or_kwlist/0","type":"type"},{"doc":"Represents the options passed to `populate_struct/3`.\nSet any value to `false` to disable checking for that kind of key.","ref":"ExConstructor.Options.html","title":"ExConstructor.Options","type":"module"}]}